# PyBatteryID

**PyBatteryID** - a shorthand for **Py**thon **Battery** Model **ID**entification - is an open-source library for data-driven battery model identification in the linear parameter-varying (LPV) framework.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install PyBatteryID.

```bash
pip install pybatteryid
```
